Maps pass type atoms to platform-specific type strings.
Supported pass types: :event_ticket, :boarding_pass, :store_card, :coupon, :generic.
Summary
Functions
Returns all supported pass types.
Returns the Apple pass.json top-level key for the given pass type.
Returns the class ID suffix for Google Wallet (e.g. "flight_class").
Returns the Google Wallet class resource name (e.g. "flightClass").
Returns the Google Wallet object resource name (e.g. "flightObject").
Returns the JWT payload key for Save to Google Wallet (e.g. "flightObjects").
Types
Functions
Returns all supported pass types.
Returns the Apple pass.json top-level key for the given pass type.
Returns the class ID suffix for Google Wallet (e.g. "flight_class").
Returns the Google Wallet class resource name (e.g. "flightClass").
Returns the Google Wallet object resource name (e.g. "flightObject").
Returns the JWT payload key for Save to Google Wallet (e.g. "flightObjects").